# Game Design Document 

_[A game design document is living document which describes the intent of the game design.  It has two goals, first to document the decisions that have been made about the game and communicate those concepts to the entire team.  Thus, it needs to be detailed enough for programmers to refer to when they need clarification about an aspect of the game.  It must be able to be updated as the game is to be built.  The need to have a game design document increases with the size of the team and length of the project.]
[For a student project the intent is to capture as much as possible of your design. The game design will be larger than what you can achieve in a semester, but you must then decide what you need to do first.  This document should be in version control so that you can see it changing and growing.  Given we are using git you could also use @name to assign parts of the design to individual members of the team. ]_

## Game details

Title: **MACSMine**

Developers: _Lama Amro, Suraj De_
 
## Overview 


 
### Game Concept 

A 2.5D representation of the age-old Minesweeper game with a moveable character controlled by a player. The stats will be recorded, and decisions will be made based on the wins (marking the mines). 


### Genre 

Casual Games - Classic Minesweeper 


### Target Audience 

Casual game lovers. 


### Game Flow Summary 

The players takes part in an exciting version of Minesweeper game, avoiding mines and uncovering tiles by using their wits and intelligence, taking hints from the highlighted numbers on the opened tiles. The aim of the game is to clear out the board based on the difficulty level chosen by the player.


### Look and Feel 

Colored texture with a near-3D scope 
 


## Gameplay and Mechanics 

 

### Gameplay 

Notice the numbers over the tiles and try to avoid the ones with mine. 



#### Game progression 

1. Clearing the board. 
2. Not exploding. 
3. High score _[addition conditional]_. 


#### Mission/challenge Structure 

High score is recorded according the fastest to win.  


#### Puzzle Structure 

The main structure is a puzzle. 


#### Objectives 

Clearing all the mines without exploding. 



### Mechanics 

    What are the rules of the game, both implicit and explicit? Each number represents the number of mines in the 3*3 square around it.
    This is the model of the universe that the game works under. Think of it as a simulation of a world. How do all the pieces interact? 



#### Physics 

Collision factors depend on the mass of the character and the gravity. 
 

#### Movement 

Main points for movement:

1. Character's movement is controlled by the arrows of the keyboard.  
2. A jump feature is available using the space key.  

Thus, by moving the characters along the tiles in a plane, with occasional jumping, the character can be moved. The tiles with mines can also be marked.


#### Objects 

The character, the mines, the numbers, the mine markers, and the tiles 

    How does the player interact with them?

The player controls the character and moves along the tiles, avoiding the mines by taking hints from the numbers highlighted. The mines can also be marked to highlighted the recognition of a mine tile without revealing.
 

#### Actions 

    What are the other interactions the player has with the game world?

if the character (controlled by the player) steps on a mine, the explosion is set up. In the reverse case, if the character avoids all the mines and reveals the rest of the tiles, it wins.


#### Economy 

    What is the economy of the game? How does it work?

There is no distinguishing economy in the game. Winning conditions may lead to new additions of buffs, in the future. 


#### Scene Flow 

List of scenes

1. Loading scene: Play, High Score, Instructions and Quit. 
2. Mode Select scene: Easy, Medium, Hard, Back.
3. Instructions scene: Instructions on how to play the game, Back to main menu, Play. 
4. Game scene: Minesweeper gameplay scene.
5. Losing scene: _Explosion effect_.
6. Winning scene: _Victory message_.

The scene flows from loading scene to mode select, where the selection will set the game. Winning and losing scenes are based upon the result of players gameplay. The instruction scene is connected to the loading scene to help the players get an insight into how to play the game. 



### Game Options 

Three modes of difficulty: 

1. Easy: 7x7 board with 10 mines,  
2. Medium: 10x10 board with 20 mines,  
3. Hard: 15x15 board with 40 mines. 
 

### Replay and Saving 

Replay happens without saving any data at this point.
 

### Cheats and Easter Eggs 

Considering the simple flow of the game, cheats are not being assessed in the game. 



## The Story, Setting, and Character 

 

### Story and Narrative 

    If there is a story component includes back story, plot elements, game progression, and cut scenes. Cut scenes descriptions include the actors, the setting, and the storyboard or script.

_Character X had been a kid, when it was taken out of its home and into the world of pain. Moving into the real scenario, it developed a sense of keen knowledge on how the harsh reality of life works. Even though estranged, it missed its home and one day decided to sneak away back to family. Gathering up the courage to head back to his original life, on one such mission, it came close to the pathway discovering an enormous minefield in front of the kingdom door. Backing away in disappointment, it pledges to gain knowledge and come back someday, finally able to reach home. With that goal in mind, it starts to train on smaller and average sized minefields, taking care of each step and finding paths quicker. Once trained, with bought buffs, it stakes its life to reach back home, just to taste happiness again._

Simple skeleton of the game has been made for now and story is to be added in later versions. 

 

### Game World 

    The setting of the game

The game is set in a dystopian world with just the tiles as the primary focus on gameplay. 

 

#### General look and feel of the World 

    Aesthetics

Color schemes and gradients have been adjusted to make the world quite appealing. 


#### Areas 

    including the general description and physical characteristics as well as how it relates to the rest of the world. (what levels use it, how it connects to other areas).

The areas have not been designated according to a set storyline, but have been directed using the modes of easy, medium and hard. 


### Characters 

    Each character should include the back story, personality, appearance, animations, abilities, relevance to the story and relationship to other characters.

The character can move by jumping over tiles. It can jump in different directions and mark the tiles that it suspects to be a mine.  

The storyline has been removed for now, but the character still has the 3d feature of moving in x, y and z axes. 


 

## Levels 

 

### Playing Levels 

    Each level should include a synopsis, the required introductory material (and how it is provided), the objectives, and the details of what happens in the level. Depending on the game, this may include the physical description of the map, the critical path that the player needs to take, and what encounters are important or incidental. 

There are no specific levels set for the game. The player needs to pick one mode (easy, medium, hard) and play the game in the same floor. The objective of the game is then to uncover the tiles without stepping on a mine. 

### Training level 

    How is onboarding managed? 

An instruction scene is provided to get accustomed to the idea of what is to be done.

## Interface 

 

### Visual System 

    If you have a HUD, what is on it?  What menus are you displaying? What is the camera model?

In terms of Headsup Display (HUD), only a timer is displayed along with an exit button in the form of a cross.
 

### Control System 

    How does the game player control the game? What are the specific commands?

Keyboard arrows are used for controlling the movements and jumping can be done using the space key.  

To mark a mine, the Numpad keys are used. To determine where to mark a mine, number 5 is used as a reference of the character’s position, and the surrounding numbers are the surrounding square around the character. 


### Audio, Music, Sound Effects 
 
suspense audio is used in the main menu scene, there is a button to mute/ unmute the audio.  

Explosion sound for the losing scene, there is a button to mute/ unmute the audio. 

No audio was chosen for the playing scene because the game needs concentration.  

 

### Help System 

Instructions for how to play the game can be found on the instructions page. 

 

## Artificial Intelligence. 

Each time the play scene is loaded, an algorithm creates mines in various positions and creates the numbers depending on the mine’s positions. 

 

### Opponent and Enemy AI 

There is no usage of an AI technology in this game. A scripted algorithm controls setting of the scene. Strategic decision making is to be done by the player to mark the mines based on the displayed numbers and avoid mine at all costs.


### Non-combat and Friendly Characters 

There are no NPCs or ally characters being used in the game. The only active character is the one controlled by the user. 


### Support AI 

No support AI are present in the game. The player has to use his own intelligence to navigate through the mine field.


### Player and Collision Detection, Path-finding. 

Collision between the character and the cover over the tiles results in removing the cover.  

Colliding with a mine tile results in an explosion and loss.  

 

## Technical 

 

### Target Hardware 

The target hardware is PC system. However, development in Unity, may give rise to cross-platform (mobile device) accessibility.


### Development Hardware and Software (including game engine) 

Unity engine was used to build the game. Developers have used their personal computers as development hardware.  


### Network requirements 

The game requires no network dependency as all the system files are integrated within the setup.




## Game Art 

 

### Key assets  

    How are they being developed.  Intended style.

1. The scenes: Developed and connected in a flow that guarantees smooth transition between them.  

2. Scripts: Small scripts were written for different functionalities. But one main Script that creates the play scene.  

3. Materials: Made to suit the game nature.  

4. Prefabs: The character, the tiles of the board, and the cover tiles were made as prefabs and are being called from a script when loading the play scene.  

 

 

 

_[This is an extension of parts of [cs.unc.edu](http://wwwx.cs.unc.edu/Courses/comp585-s11/585GameDesignDocumentTemplate.docx) ]_
