# Individual Report [Suraj De]

This report consists of 4 sections describing the good code, bad code, score weightage and the final reflection on my part.

## Bad Code

For the bad code portion, i would like to stress on the chain opening section of MACSmine game. In a traditional minesweeper game, based on the response of a user to select a certain tile, the surrounding areas are affected. For example, if the number underneath the selected tile is zero (logically implying that there are no surrounding mines), then the other tiles around it would be opened, depending on what the tiles are. If the nearby tile is zero again, then the same functionality will transfer to those tiles and the surrounding tiles will be opened as well. This goes on till no such opening results in a zero tile. If the selected option is a number, then only that specific tile will open. 

For this code, i tried to implement the chain thing by creating a loop to check all the surrounding areas. Now, for the surrounding areas, there were three instances which could be possible. 

![Three individual tile section](/uploads/d43d390fd237ea1617fba993af24f12f/image.png)

- For any tile in the middle section, the surrounding areas are represented using 8 locations. So, if we consider numpad 5 as the location of the opening, then keypad numbers from 1 to 9 except number 5 would be the surrounding areas. And respectively all the 8 locations would be opened. 
- For any tile in the left boundary, the surrounding areas are represented with top and bottom tile with the right side tiles. So, if we take the example of 5th to be the opening tile, then numpad 2, 3, 6, 8, 9 would be the neighbours.
- For a tile in the right boundary, the selection is nearly reversed. This time the neighbours are numbers 1, 2, 4, 7, 8 for keypad 5. This is to ensure that this selection doesnt bleed into the next rows.

To create structure, lots of if conditions were used to isolate the three sections and create the chain opening. The functionality worked initially but then, there were complications extending it to the bigger levels. This meant that the chain system wasn't flying off and after trying to come up with a plan to use recursion, i decided to give it another try. There were bugs popping out in the graphical system once the chain thing was done, but the main issue was that due to the recursion iteration, the game state was becoming static until the whole calculation was completed. This meant that the character was just stuck in a certain position, removing the facade of continuous movement to the player. This was a major flaw as the main element of character introduction was to have a difference in approach to the logic.

![Bad Code if conditions](/uploads/2745163c8d8d567e7b7ee77e6abbc7e5/image.png)

Thus, due to time limitation, the code was suited to keep the opening of surrounding tiles to one level and it was implied that the user had to use their logic to understand which tile to open. For instance, zero tiles represent zero mines surrounding it, so they should open the safe surrounding areas.

## Good Code

According to me, the good code section can be considered the game logic section. It was quite time consuming to come up with a logic that could enable the game logic part of displaying numbers as I wanted to create an idea different from the past minesweeper approaches. The earlier minesweeper versions, as per a bit of research, used probability to allocate mines and then considering the 2D aspect of the tiles, the sprites would be used to calculate the location and subsequently go through the number allocation. 

Our game of MACSmine, however, was being built as a 3D system. Thus, there was usage of 3 dimensional coordinates to create the whole structure. This meant that the complexity of the algorithm would take a hit if the calculations are too vast. Thus, I decided to reduce the implementation difficulty by trying to change the whole distribution from 2 dimensional array to one dimensional array to reduce the time a bit. Now, executing such a logic was difficult considering the difference in whole structure with the removal of probabilistic effect. So, i decided to divide the whole layering scheme into 3 primary groups:

- **Mine Tiles** : This tile gameobject was used to represent the mine tile. The calculations for the minetile was done using the 3 separate sections of neighbouring tile logic. The prefabs were built in Unity which were being invoked into the code and a tile was placed based on a random selection of mine locations in the one dimensional array. 

![Mine Tile Generation](/uploads/a3f21f0edaa987e90eb2d709adb8ff2f/image.png)

- **Zero Tiles** : This tile gameobject was used to represent the zero tile, as in those tiles which have no mines in its immediate surrounding. The locations of such tiles were also saved to further use it in the future for the chain opening functionality.

- **Numbered Tiles** : The numbered tiles gameobject represented the tiles being laid to give hints to the user for the surrounding mines.

![Tile Instantiation](/uploads/f2fe1510575ee68931e10f28d6024225/image.png)

Once the gameobjects were created, a one dimensional loop would run, the value of which, would produce the row and column value in a grid. Based on this grid, the tiles would be laid and the board would be created. 

![Board Creation](/uploads/ee85bb3601f2c3da07e924f6a95d557e/image.png)

This reduced the complexity a bit, considering the dimensional nested loop was reduced down to one straight loop. 

## Score weightage

| Description | Weightage |
| ------ | ------ |
| Gameplay video | 5 |
| Code video | 15 |
| Good code | 20 |
| Bad code | 20 |
| Development Process | 20 |
| Reflection | 20 |

## Reflection

I have always been passionate about games, almost to the level of obsession. This however changed to a big extent, when I got curious about how these games are being created and delivered. This search to find answers and learn about the concepts, made me opt for this course. Seeing the various functionalities taught in the course in different areas like the usage of Unity and detection mechanisms of gameobjects, I admit to have been anxious about whether I made the right decision. But then the love for gaming took over and set me on this path to educate myself on the ideas of game building.  

The main thing which kept me going was the progression of how lines of codes and images transformed into an interacting story telling scheme. The introduction of C# in Unity, did pose a challenge initially as i had never worked on the language, but with time, it seemed to grow on me. Unity was another key aspect of motivation. The initial discussion during the team members was to decide which game engine would be suitable to use. Considering all of the involved members, were just starting into the game building, both Unreal engine and Unity seemed uncharted territories. That being said, Unity was more popular among the members as few indie games played on various platforms, had usage of Unity in them. Thus, Unity was selected for the base engine. Following that, plenty of good ideas were pitched and laid out on the table. Among them, the concept of creating a 3D variant of minesweeper game was picked due to its simplicity and an age-old nostalgia of gameplay. 

As the time went on during the course, the priorities started to come up. Two of the group members had to opt out of the experience due to workload issues. This meant that the journey limited down to two members. We decided to take two separate parts of the work and i was entrusted with the critical code part. We decided to segregate our work and have regular meetings to discuss progress. This helped us to individually take charge of our area of interest and i found that solving problems as part of game logic really fascinated me. For weeks, i dove into the development of some kind of logic to replicate the functionalities of minesweeper but with a novel approach. As the decided date for primary integration approached, things started to fall into place as I was able to create a new variant logic. Even though the logic was a bit messy with ideas, I was really happy on what the end product came to. 

The mode of communication was kept to mostly physical and occassionally online to cope with the covid restrictions and the low team size. Physical meetup especially helped in being transparent on every aspect of game design and implementation. The synchronization of the ideas and concepts, from the class and in general among the members, helped us to keep a steady pace in finishing the game at a good pace. Both of us, did face challenges in terms of Unity engine being slow, or having update errors, but the backup storage of game files in gitlab made it easy for either person to pick up the codes and graphical elements, and change them according to needs. We did, however, maintain the sense of code equilibrium by informing each other of the changes before committing them. 

Overall, it was a wonderful experience to build a game from scratch. This course really fueled my passion of gaming to a different level and hopefully, this stage is just the beginning of my game building journey.
